@@ -1,7 +1,7 @@
 
 module Hoogle.Score.All(
     module Hoogle.Score.Scoring,
-    Score, TypeCost(..), TextMatch(..), textScore, typeScore, scoreCosts, scoreExact, cost
+    Score, TypeCost(..), TextMatch(..), textScore, typeScore, scoreCosts, cost
     ) where
 
 import Hoogle.Score.Scoring
